Crate nwr

Crate nwr 

Structs

Taxon

Functions

batch_exec
Helper function to handle batch execution of SQL statements
connect_txdb
Connect taxonomy.sqlite in this dir
find_rank
Find rank in lineage
get_all_descendent
All direct or indirect descendents of the Node. The ID given as argument is included in the results.
get_ancestor
Retrieve the ancestor
get_descendent
All direct descendents of the Node, not a recursive fetchall
get_lineage
All Nodes to the root (with ID 1)
get_nwr_dir
Get nwr working directory from command line args or default path
get_tax_id
Names to Taxonomy IDs
get_taxon
IDs to Nodes
nwr_path
nwr working path
term_to_tax_id
Convert terms to Taxonomy IDs Accepted forms: ID; “scientific name”; scientific_name