Structs
Functions
- batch_
exec - Helper function to handle batch execution of SQL statements
- connect_
txdb - Connect taxonomy.sqlite in this dir
- find_
rank - Find rank in lineage
- get_
all_ descendent - All direct or indirect descendents of the Node. The ID given as argument is included in the results.
- get_
ancestor - Retrieve the ancestor
- get_
descendent - All direct descendents of the Node, not a recursive fetchall
- get_
lineage - All Nodes to the root (with ID 1)
- get_
nwr_ dir - Get nwr working directory from command line args or default path
- get_
tax_ id - Names to Taxonomy IDs
- get_
taxon - IDs to Nodes
- nwr_
path - nwr working path
- term_
to_ tax_ id - Convert terms to Taxonomy IDs Accepted forms: ID; “scientific name”; scientific_name